# Chapter 13: Strategy Visualization and Report Analysis

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 13 章：策略可视化与报表分析](../../zh/textbook/13_visualization.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch13_visualization.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch13_visualization.py)
  - Extended example: [examples/11_plot_visualization.py](https://github.com/akfamily/akquant/blob/main/examples/11_plot_visualization.py)
  - Guide: [Visualization Guide](../guide/visualization.md)
